<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddFournisseur extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("fournisseur_statut", ['id' => false, 'primary_key' => ["fournisseur_statut_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('fournisseur_statut_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('fournisseur_statut_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_statut_id'])
            ->create();

        $this
            ->table("fournisseur", ['id' => false, 'primary_key' => ["fournisseur_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('fournisseur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('fournisseur_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_id'])
            ->addColumn('fournisseur_image', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom'])
            ->addColumn('fournisseur_date_ajout', 'datetime', ['null' => false, 'default' => '0000-00-00 00:00:00', 'after' => 'fournisseur_image'])
            ->addColumn('fournisseur_date_modif', 'datetime', ['null' => false, 'default' => '0000-00-00 00:00:00', 'after' => 'fournisseur_date_ajout'])
            ->addColumn('fournisseur_rue', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_date_modif'])
            ->addColumn('fournisseur_cp', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_rue'])
            ->addColumn('fournisseur_ville', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_cp'])
            ->addColumn('fournisseur_pays', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_ville'])
            ->addColumn('fournisseur_livraison', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_pays'])
            ->addColumn('fournisseur_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_livraison', 'signed' => false])
            ->addForeignKey('fournisseur_statut_id', 'fournisseur_statut', 'fournisseur_statut_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addIndex(['fournisseur_statut_id'], ['name' => "fournisseur_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("fournisseur_boutique", ['id' => false, 'primary_key' => ["fournisseur_boutique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('fournisseur_boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('fournisseur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_boutique_id', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_id', 'signed' => false])
            ->addColumn('fournisseur_boutique_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id'])
            ->addForeignKey('fournisseur_id', 'fournisseur', 'fournisseur_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['fournisseur_id', 'boutique_id'], ['name' => "fournisseur_id_2", 'unique' => true])
            ->addIndex(['fournisseur_id'], ['name' => "fournisseur_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->addIndex(['fournisseur_boutique_statut_id'], ['name' => "fournisseur_boutique_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("fournisseur_nom", ['id' => false, 'primary_key' => ["fournisseur_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('fournisseur_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('fournisseur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_nom_id', 'signed' => false])
            ->addColumn('langue_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'fournisseur_id', 'signed' => false])
            ->addColumn('fournisseur_nom_desc', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'langue_id'])
            ->addColumn('fournisseur_nom_desc_court', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom_desc'])
            ->addColumn('fournisseur_nom_meta_title', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom_desc_court'])
            ->addColumn('fournisseur_nom_meta_desc', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom_meta_title'])
            ->addColumn('fournisseur_nom_meta_kw', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom_meta_desc'])
            ->addColumn('fournisseur_nom_meta_other', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'fournisseur_nom_meta_kw'])
            ->addForeignKey('fournisseur_id', 'fournisseur', 'fournisseur_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id', 'fournisseur_id'], ['name' => "langue_id_2", 'unique' => true])
            ->addIndex(['fournisseur_id'], ['name' => "fournisseur_id", 'unique' => false])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->create();
    }
}
