<?php

namespace Controller;

use Breadcrumb;
use Texte;
use Tracking;
use Panier;
use Boutique;
use Commande;
use Tpe;

use Symfony\Component\Routing\Annotation\Route;

/**
 * Class PaymentController
 * @package Controller
 */
class PaymentController extends Controller
{

    /**
     * @Route(
     *      path         = "/checkout_transaction.html",
     *      name         = "paiement_actif"
     * )
     *
     * @return mixed
     */
    public function actif()
    {

        $panier = Panier::getInstance();

        $reference = $panier->getReference();
        if (empty($reference)) {
            return $this->redirect($this->generateUrl('panier'));
        }

        $payments = $panier->getPayment();
        if (empty($payments[0]->paiement_class)) {
            return $this->redirect($this->generateUrl('panier'));
        }

        $banque = new $payments[0]->paiement_class(Boutique::getInstance()->getConfig());

        // calcul du montant a payer et application de la tva
        $isTva = $panier->isTva();
        list($aPayerHT, $aPayerTTC) = $panier->getAPayer();
        $amount = ($isTva) ? $aPayerTTC : $aPayerHT;

        $this->template->assign('isTva', $isTva);

        $frmCB = $banque->requestFromPanier($panier, $amount);
        $this->template->assign('frmCB', $frmCB);

        /*$tracking = new Tracking;
        $tracking->get('paiementActif',array('tpe_reference_id' => $reference), $smarty);*/

        $this->template->assign('paiement', $payments[0]);

        $texte = new Texte();
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_panier', 'Mon panier'));
        $bd->add($texte->getOneOrCreate('paiement', 'Paiement'));

        return $this->render('paiement_actif.tpl');
    }

    /**
     * @Route("/traitement_{class}.html", name="traitement_actif", requirements = { "class" = "[a-zA-Z0-9-_]+" })
     *
     * @return mixed
     */
    public function traitement()
    {

        $className = ucfirst($this->request->get('class'));
        if ($className != 'Tpe') {
            $className = 'Shopbydedi\Payment\\' . $className;
        }

        if (class_exists($className) == false) {
            return $this->redirect($this->generateUrl('order'));
        }

        return call_user_func_array(
            array(new $className(Boutique::getInstance()->getConfig()), "response"),
            array(array_merge($this->request->query->all(), $this->request->request->all()))
        );
    }

    /**
     * @Route(
     *      path         = "/payment_success.html",
     *      name         = "paiement_success",
     *      defaults     = {"role" = "customer"},
     * )
     *
     * @return mixed
     */
    public function success()
    {

        $tpl_vars = [];
        $cart = Panier::getInstance();
        $session = $this->getSession();

        if ($session->has('commande_id')) {
            $commandeId = $session->get('commande_id');
        }

        if (empty($commandeId)) {
            $ref = $cart->getReference();
            if (!empty($ref)) {
                $tpe = new Tpe($cart->getReference());
                $commandeId = $tpe->commande_id;
            }
        }

        if (!empty($commandeId)) {
            $texte = new Texte();
            $commande = new Commande($commandeId);

            $tpl_vars['commande'] = $commande->toArray();

            if (!empty($commande->paiement_nom_txt_template)) {

                $commande->paiement_nom_txt_template = str_replace("%MONTANT%", $commande->montant_a_paye, $commande->paiement_nom_txt_template);
                $commande->paiement_nom_txt_template = str_replace("%DATE%", $commande->commande_date, $commande->paiement_nom_txt_template);
                $commande->paiement_nom_txt_template = str_replace("%REF%", $commande->commande_id, $commande->paiement_nom_txt_template);
                $commande->paiement_nom_txt_template = str_replace("%EMAIL%", $commande->client_email, $commande->paiement_nom_txt_template);
                if (!empty($tags)) {
                    foreach ($tags as $key => $value) {
                        $commande->paiement_nom_txt_template = $texte->replaceIfTag(
                            mb_strtoupper($key),
                            $value,
                            $commande->paiement_nom_txt_template
                        );
                    }
                }
            }

            $tracking = new Tracking();
            $tracking->get('paiementPassif', array('commande_id' => $commandeId), $this->template);

            $cart->init();
        }

        return $this->render('paiement_success.tpl', $tpl_vars);
    }

    /**
     * @Route("/payment_error.html", name="payment_error")
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function error()
    {
        $tpl_vars['error'] = true;

        return $this->render('paiement_success.tpl', $tpl_vars);
    }
}
