<?php

namespace Controller;

use Adresse;
use DediException;
use Paiement;
use Pays;
use Shopbydedi\Client;
use Shopbydedi\Payment\PaypalExpress;
use Symfony\Component\HttpFoundation\Request;
use Texte;
use Panier;
use Boutique;
use Commande;

use Symfony\Component\Routing\Annotation\Route;

/**
 * Class PaymentController
 * @package Controller
 */
class PaypalExpressController extends Controller
{

    /**
     * @var PaypalExpress
     */
    protected $paypalExpress;

    /**
     * @param Request $request
     *
     * @throws \DediException
     */
    public function __construct(Request $request)
    {
        parent::__construct($request);

        $this->paypalExpress = new PaypalExpress(Boutique::getInstance()->getConfig());
    }

    /**
     * @Route(
     *      path         = "/paypal-express/cart",
     *      name         = "paypal_express_cart"
     * )
     *
     * @return mixed
     */
    public function cart()
    {

        $panier = Panier::getInstance();
        list($aPayerHT, $aPayerTTC) = $panier->getAPayer();
        try {
            $url = $this->paypalExpress->request($panier, $aPayerTTC);
        } catch (\Exception $e) {
            $url = $this->generateUrl('panier');
        }

        if (empty($url)) {
            $url = $this->generateUrl('panier');
        }

        return $this->redirect($url);
    }

    /**
     * @Route(
     *      path         = "/paypal-express/login",
     *      name         = "paypal_express_login"
     * )
     *
     * @return mixed
     */
    public function login()
    {

        $panier = Panier::getInstance();
        $client = new Client();
        $pays = new Pays();
        $session = $this->getSession();
        $session->set('token', $this->request->get('token'));
        $session->set('paymentId', $this->request->get('paymentId'));
        $session->set('PayerID', $this->request->get('PayerID'));

        $paymentDetails = $this->paypalExpress->getPaymentDetails($this->request->get('paymentId'));

        $payerInfos = $paymentDetails->getPayer()->getPayerInfo();
        $email = $payerInfos->getEmail();
        $addr = $payerInfos->getShippingAddress();

        $cl = $client->get(array('client_email' => $email));

        if (empty($cl)) {
            $param = array();
            $param['civilite_id'] = 1;
            $param['client_nom'] = $payerInfos->getLastName();
            $param['client_prenom'] = $payerInfos->getFirstName();
            $param['client_ddn'] = $payerInfos->getBirthDate();
            $param['client_email'] = $email;
            $param['client_telephone'] = '';
            $param['client_password'] = '';
            $param['client_newsletter_id'] = 1;

            $param['adresse_rue'] = $addr->getLine1();
            $param['adresse_rue2'] = $addr->getLine2();
            $param['adresse_cp'] = $addr->getPostalCode();
            $param['adresse_ville'] = $addr->getCity();
            $param['adresse_etat'] = '';

            $paysClient = $pays->get(['pays_iso_code_2' => $addr->getCountryCode()]);
            $param['pays_id'] = $paysClient[0]['pays_id'];
            $id = $client->add($param);
        } else {
            $id = $cl[0]['client_id'];
        }

        $newClient = new Client($id);

        $panier->setCustomer($newClient);

        $client->setSession($session, $newClient->toArray());

        $adresse = new Adresse($newClient->adresse_id);

        $panier->setAddressBilling($adresse);
        $panier->setAddressShipping(clone $adresse);

        $panier->calculateShipping();

        $url = $this->generateUrl('recapitulatif');

        return $this->redirect($url);

    }

    /**
     * @Route(
     *      path         = "/paypal-express/payment",
     *      name         = "paypal_express_payment"
     * )
     *
     * @return mixed
     */
    public function payment()
    {
        $flashBag = $this->getFlashBag();
        $texte = new Texte();
        $session = $this->getSession();
        $panier = Panier::getInstance();

        list($aPayerHT, $aPayerTTC) = $panier->getAPayer();

        if ($this->request->get('paiement_id') == false && $aPayerHT > 0) {
            $flashBag->add(
                'error',
                $texte->getOneOrCreate('errSelectPaiement', 'Vous devez selectionner un mode de paiement')
            );
        }

        if ($this->request->get('cgv') == false) {
            $flashBag->add(
                'error',
                $texte->getOneOrCreate('errValidCGV', 'Vous devez valider les CGV pour passer au paiement')
            );
        }

        if ($flashBag->has('error') == false) {

            // ajouter le paiement au panier
            $panier->initPaiement();
            $paiement = new Paiement($this->request->get('paiement_id'));

            if ($paiement instanceof Paiement) {

                $panier->addPayment($aPayerTTC, $paiement);
                $panier->setDeviceType($this->getDeviceType());

                // on envoie la demande de débit du compte PayPal
                $payment = $this->paypalExpress->response([
                    'paymentId' => $session->get('paymentId'),
                    'PayerID' => $session->get('PayerID'),
                ]);

                // si le payment est ok, status "approved"
                if ($payment->getState() == "approved") {
                    try {
                        $commande = new Commande();
                        $session->set('commande_id', $commande->saveFromPanier($panier));
                    } catch (DediException $e) {
                        $flashBag->add('error', $e->getMessage());
                    }

                    if ($session->has('commande_id')) {
                        // On vide tout
                        $panier->init();
                        $session->remove('token');
                        $session->remove('paymentId');
                        $session->remove('PayerID');
                        $response = $this->redirect($this->generateUrl('paiement_success'));
                    }
                } else {
                    $flashBag->add(
                        'error',
                        $texte->getOneOrCreate('errPaymentPaypalExpress', 'Une erreur est survenue lors de la demande de débit. Veuillez recommencer')
                    );
                }
            }
        }

        if ($flashBag->has('error')) {
            $response = $this->redirect(
                $this->generateUrl('recapitulatif')
            );
        }

        return $response;

    }
}
