/**
 * Depends on jQuery, Messager
 */

/***
 * Ctor.
 *
 * @param isOrderPage
 * @constructor
 */
var Address = function (isOrderPage) {
    this.messager = new Messager();
    this.orderPage = (isOrderPage === true);
    this.modes = {
        "update": "update",
        "view": "view",
        "create": "create"
    };
    this.defaultMode = (this.orderPage === true) ? this.modes.view : this.modes.update;
    this.currentMode = this.defaultMode;

    this.multiple = (jQuery(".addrAjax").length > 1);

    this.idleTime = 1500;

    this.currentCountry = null;

    window.address = this;//todo : remove this
};

/***
 * Make base setup to prepare forms
 */
Address.prototype.setup = function () {
    var that = this;
    var addressWrapper = jQuery(".addrAjax");

    that.currentCountry = addressWrapper.find("select[name='pays_id']:first").val();

    // select address
    addressWrapper.on("change", "select.addrSelector", function () {
        that.select(jQuery(this));
    });

    // imitate submit using anchors
    addressWrapper.on("click", "a.fakeSub", function (e) {
        jQuery(this).parents("form:first").trigger("submit");
        e.preventDefault();
        return false;
    });

    // handle basic form submission, using form serialization and its attributes
    addressWrapper.on("submit", ".addrCreate form, .addrUpdate form", function (e) {
        return that.formSubmit(jQuery(this), e);
    });

    // toggle address editor modes
    addressWrapper.on("click", ":not(.disabled) a[data-addr-mode]", function (e) {
        var btn = jQuery(this);
        var wrap = btn.parents(".addrAjax:first");
        that.mode(btn.data("addr-mode"), wrap);
        e.preventDefault();
        return false;
    });

    // toggle address actions
    addressWrapper.on("click", ":not(.disabled) a[data-addr-ajax]", function (e) {
        var btn = jQuery(this);
        var wrap = btn.parents(".addrAjax:first");
        var defaults = {
            type: btn.data("addr-method"),
            url: btn.data("addr-action"),
            dataType: "json",
            success: function (response) {
                that.handleResponse(response, wrap);
            }
        };
        jQuery.ajax(defaults);
        e.preventDefault();
        return false;
    });

    // lock billing address
    if (this.orderPage) {
        this.lockSwitch();
        that.mode(that.modes.view);
        var locker = jQuery('#sameAdress');
        var lockerWrap = locker.parents(".addrAjax").first();
        if (jQuery(".addrSelector.shipping").val() == jQuery(".addrSelector.billing").val()) {
            that.lock(lockerWrap);
            locker.attr("checked", "checked");
        } else {
            that.unlock(lockerWrap);
            locker.removeAttr("checked");
        }
    }
};

/***
 * Change editor mode and address sub-blocks visibility
 *
 * @param mode
 * @param wrap
 */
Address.prototype.mode = function (mode, wrap) {
    if (!wrap) {
        wrap = jQuery("body");
    }

    switch (mode) {
        case "update":
            wrap.find(".addrUpdate").show();
            wrap.find(".addrCreate, .addrView").hide();
            this.currentMode = mode;
            break;
        case "create":
            wrap.find(".addrCreate").show();
            wrap.find(".addrUpdate, .addrView").hide();
            this.currentMode = mode;
            break;
        case "view":
        default:
            wrap.find(".addrView").show();
            wrap.find(".addrCreate, .addrUpdate").hide();
            this.currentMode = mode;
            break;
    }
};

/***
 * Make the lock checkbox subscribe to click event in order to lock/unlock the second block
 */
Address.prototype.lockSwitch = function () {
    var that = this;
    jQuery('#sameAdress').on("click", function () {
        var lock = jQuery('#sameAdress');
        var wrap = lock.parents(".addrAjax:first");
        if (lock.is(':checked')) {
            that.lock(wrap);
            that.mode(that.modes.view, jQuery(".addrAjax.billing"))
        } else {
            that.unlock(wrap);
        }
    });
};

/***
 * Bind selects when multiple edition forms are present, disable second one
 *
 * @param wrapper
 */
Address.prototype.lock = function (wrapper) {
    this.locked = true;
    var defaultWrap = jQuery(".addrAjax.shipping");
    this.copyForms(defaultWrap);
    wrapper.find(".addrSelector, .addrView, .addrCreate, .addrUpdate").addClass("disabled").css({'opacity': 0.5});
    wrapper.find(":input :not(.sameAddress), select").attr("disabled", "disabled");
    defaultWrap.find(".same_address").val("1");
    this.copySelects(defaultWrap);// must be done after inputs disable
};

/***
 * Unbind selects when multiple edition forms are present
 *
 * @param wrapper
 */
Address.prototype.unlock = function (wrapper) {
    var defaultWrap = jQuery(".addrAjax.shipping");
    wrapper.find(".addrSelector, .addrView, .addrCreate, .addrUpdate").removeClass("disabled").css({'opacity': 1});
    wrapper.find(":input, select, option").removeAttr("disabled");
    defaultWrap.find(".same_address").val("");
    this.locked = false;
};

/***
 * Handle json returns, feed the DOM, display errors and change editor mode (view|update|create) following actions
 *
 * @param response
 * @param wrap
 */
Address.prototype.handleResponse = function (response, wrap) {
    var oldWrap = wrap;
    if (this.locked === true) {
        wrap = jQuery(".addrAjax");
    }

    if (response.html && response.html.view) wrap.find(".addrView").html(response.html.view);
    if (response.html && response.html.update) wrap.find(".addrUpdate").html(response.html.update);
    if (response.html && response.html.selector) {
        /* avoid to break selects forms infos, restrict to initial wrap */
        if (oldWrap) {
            oldWrap.find(".addrSelec").html(response.html.selector);
        }
        this.copySelects(oldWrap);
    }

    if (response.delete) {
        setTimeout(function(){
            wrap.find(".addrSelec .addrSelector option:first").trigger("change");
        }, this.idleTime);
    }

    if (response.create) {
        wrap.find(".addrSelec .addrSelector").val(response.create).trigger("change");
        this.createReset(wrap);
    }

    if (response.update) {
        wrap.find(".addrSelec .addrSelector").val(response.update);
        oldWrap.trigger("change");
    }

    if (response.error) this.messager.handle(oldWrap.find("div.error"), response.error);
    if (response.success) this.messager.handle(oldWrap.find("div.success"), response.success);

    if (response.error == undefined) {
        this.handleCountry();
    }
};

/***
 * Used to update viewport, bring back create,update, and view templates for selected address
 *
 * @param el
 */
Address.prototype.select = function (el) {
    var that = this;
    if (el.val() == "") return;

    var form = el.parents("form:first");
    var wrap = el.parents(".addrAjax:first");

    jQuery("div.error,div.success").html(""); // empty errors placeholders

    if (el.val() == "create") {
        that.mode("create", wrap);
        return;
    }

    var defaults = {
        type: form.attr("method"),
        url: form.attr("action"),
        data: form.serialize(),
        dataType: "json",
        success: function (response) {
            if (that.locked === true) {
                jQuery("select.addrSelector").val(el.val());
                that.copyForms(wrap);
            }
            that.handleResponse(response, wrap);
            that.mode(that.defaultMode);
        }
    };
    jQuery.ajax(defaults);
};

/***
 * Used to handle create & update actions, overriding submit handler for both forms
 *
 * @param form
 * @param event
 * @returns {boolean}
 */
Address.prototype.formSubmit = function (form, event) {
    var that = this;
    var wrap = form.parents(".addrAjax:first");
    var data = form.serialize();
    var defaults = {
        type: form.attr("method"),
        url: form.attr("action"),
        data: data,
        dataType: "json",
        success: function (response) {
            that.handleResponse(response, wrap);
            if (that.multiple && jQuery(".addrSelector.billing").val() == jQuery(".addrSelector.shipping").val()) {
                that.copyForms(wrap);
            }
            if (!response.error && response.success) that.mode(that.defaultMode, wrap);
        }
    };
    jQuery.ajax(defaults);
    event.preventDefault();
    return false;
};

/***
 * Used to copy forms and views from shipping to billing when locked
 *
 * @param wrap
 */
Address.prototype.copyForms = function (wrap) {
    if (!this.multiple) return;
    var srcNode = wrap;
    var destNode = jQuery(".addrAjax.billing");
    if (srcNode.hasClass("billing")) {
        destNode = jQuery(".addrAjax.shipping");
    }
    var items = ["addrView", "addrCreate", "addrUpdate"];
    for (var i in items) {
        destNode.find("." + items[i]).html(srcNode.find("." + items[i]).html());
    }
};

/***
 *  Used to update address labels in both list when we have multiple editors
 *
 * @param wrap
 */
Address.prototype.copySelects = function (wrap) {
    if (!this.multiple) return;
    var mainSelect = wrap.find(".addrSelector:first");
    var secondSelect = jQuery(".addrAjax .addrSelector.billing");

    if (mainSelect.hasClass("billing")) {
        secondSelect = jQuery(".addrAjax .addrSelector.shipping");
    }

    if (this.locked === true) {
        secondSelect.html(mainSelect.html());
    } else {
        var old = secondSelect.val();
        secondSelect.html(mainSelect.html()).val(old);
    }
};

/***
 * Used to free creation form after successful attempt
 *
 * @param wrap
 */
Address.prototype.createReset = function (wrap) {
    var form = wrap.find(".addrCreate");
    form.find(":input[type=text]").val("");
};


Address.prototype.handleCountry = function(){
    var old = this.currentCountry;

    var id = jQuery(".addrAjax select[name='pays_id']:first");
    if(this.orderPage) {
        id = jQuery(".addrAjax.shipping select[name='pays_id']:first");
    }
    this.currentCountry = id.val();

    // if(this.currentCountry != old && this.orderPage) {
    if(this.orderPage) {
        window.location.reload();//refresh transporter
    }
};